import axios from "axios";
import qs from "qs";
import wallet from "./wallet";
import OtcApi from "./otc";
import {app} from "./app";

/**
 * 注：
 * post请求  参数统一用 qs.stringify(params)
 * get请求不用
 */

// const sysconfApi = "http://127.0.0.1:9131";
// const loginApi = "http://127.0.0.1:9121";
// const userApi = "http://127.0.0.1:9101";
const trainApi = app.trainUrl;
const sysconfApi = app.sysconfUrl;
const loginApi = app.loginUrl;
const userApi = app.userUrl;
const cctApi = app.cctUrl;
const ethApi = app.ethUrl;
const currencyApi = app.currencyUrl;
const btcApi = app.btcUrl;
const eosApi = app.eosUrl;
const c2cApi = app.c2cUrl;
const appCurrencyApi = app.appCurrencyUrl;
const botApi = app.botUrl;

export const FILE_URL = app.FILE_URL_APP;
// export const FILE_URL = "http://127.0.0.1:8088/";

/**
 * 实训管理模块 Train
 */
export const Train = new (class {
    constructor() {
        this.getCaseListApi = trainApi + "/trainCaseManage/list"; //实训管理列表
        this.insertCaseApi = trainApi + "/trainCaseManage/add";//添加实训案例
        this.updateCaseApi = trainApi + "/trainCaseManage/edit";//修改实训案例
        this.delCaseApi = trainApi + "/trainCaseManage/remove";//删除实训案例
        this.getCaseDetailApi = trainApi + "/trainCaseManage/detail";//获取实训案例详情
        this.getTargetListApi = trainApi + "/trainCaseManage/targetList";//量化指标列表
    }

    //实训案例管理列表
    getCaseList(params) {
        return axios
            .post(this.getCaseListApi, qs.stringify(params), {headers: {requestType: "noToken"}})
            .then(res => res.data);
    }
    //添加
    insertCase(params) {
        return axios
            .post(this.insertCaseApi, qs.stringify(params,{allowDots: true }))
            .then(res => res.data);
    }
    //修改
    updateCase(params) {
        return axios
            .post(this.updateCaseApi, qs.stringify(params,{allowDots: true }))
            .then(res => res.data);
    }
    //删除
    delCase(params) {
        return axios
            .post(this.delCaseApi, qs.stringify(params))
            .then(res => res.data);
    }

    //实训案例详情
    getCaseDetail(params) {
        return axios
            .get(this.getCaseDetailApi, {params: params})
            .then(res => res.data);
    }

    //量化指标列表
    getTargetList(params) {
        return axios
            .get(this.getTargetListApi, {params: params})
            .then(res => res.data);
    }
})();

/**
 * 用户管理api模块
 */
export const User = new (class {
    constructor() {
        this.getUserListApi = userApi + "/user/listSearchUser"; //用户列表
        this.selectUserInfoApi = userApi + "/user/selectUserInfo"; //用户信息
        this.listWhitelistApi = userApi + "/userList/listWhitelist"; //白名单
        this.delWhitelistApi = userApi + "/userList/delWhitelist"; //删除白名单数据
        this.listBlacklistApi = userApi + "/userList/listBlacklist"; //黑名单
        this.delBlacklistApi = userApi + "/userList/delBlacklist"; //删除黑名单数据
        this.listUserLoginLogApi = userApi + "/userLoginLog/listUserLoginLog"; //登录日志
        this.realNameAuditApi = userApi + "/user/realNameAudit"; //实名审核查询
        this.selectUserAuthenticationInfoApi =
            userApi + "/userAuthentication/selectUserAuthenticationInfo"; //实名审核用户基本信息
        this.selectLowAuthApi = userApi + "/userAuthentication/selectLowAuth"; //初级实名审核信息
        this.selectHighAuthApi = userApi + "/userAuthentication/selectHighAuth"; //高级实名审核信息
        this.selectLowRemarkApi = userApi + "/userAuthentication/selectLowRemark"; //初级未认证原因
        this.selectHighRemarkApi = userApi + "/userAuthentication/selectHighRemark"; //高级未认证原因
        this.passLowAuthApi = userApi + "/userAuthentication/passLowAuth"; //提交初级审核
        this.rejectLowAuthApi = userApi + "/userAuthentication/rejectLowAuth"; //驳回初级审核
        this.passHighAuthApi = userApi + "/userAuthentication/passHighAuth"; //提交高级审核
        this.rejectHighAuthApi = userApi + "/userAuthentication/rejectHighAuth"; //驳回高级审核
        this.listUserListByUserIdApi = userApi + "/userList/listUserListByUserId"; //查询用户黑白名单
        this.addBlacklistApi = userApi + "/userList/addBlacklist"; //添加黑名单
        this.addWhitelistApi = userApi + "/userList/addWhitelist"; //添加白名单
        this.delBlacklistApi = userApi + "/userList/delBlacklist"; //删除黑白名单
        this.listSearchUserAssetApi = userApi + "/user/listSearchUserAsset"; //查询用户资产
        this.updateMobilePhoneApi = userApi + "/user/updateMobilePhone"; //修改用户手机号码
        this.updateIdentityCodeApi = userApi + "/user/updateIdentityCode"; //修改用户身份证号码
        this.selectUserAuthenticationApi = userApi + '/userAuthentication/selectUserAuthentication'; //查询用户认证信息
        this.authenticationListApi = userApi + '/userAuthentication/selectAuthenticationList'; //查询用户认证信息
    }

    //审核列表
    authenticationList(params) {
        return axios
            .post(this.authenticationListApi, qs.stringify(params))
            .then(res => res.data);
    }

    //用户列表
    getUserList(params) {
        return axios
            .post(this.getUserListApi, qs.stringify(params))
            .then(res => res.data);
    }

    //用户信息
    selectUserInfo(params) {
        return axios
            .post(this.selectUserInfoApi, qs.stringify(params))
            .then(res => res.data);
    }

    //白名单
    listWhitelist(params) {
        return axios
            .get(this.listWhitelistApi, {
                params: params
            })
            .then(res => res.data);
    }

    //删除白名单数据
    delWhitelist(params) {
        return axios
            .post(this.delWhitelistApi, qs.stringify(params))
            .then(res => res.data);
    }

    //黑名单
    listBlacklist(params) {
        return axios
            .get(this.listBlacklistApi, {
                params: params
            })
            .then(res => res.data);
    }

    //删除黑名单数据
    delBlacklist(params) {
        return axios
            .post(this.delBlacklistApi, qs.stringify(params))
            .then(res => res.data);
    }

    //登录日志
    listUserLoginLog(params) {
        return axios
            .post(this.listUserLoginLogApi, qs.stringify(params))
            .then(res => res.data);
    }

    //实名审核查询
    realNameAudit(params) {
        return axios
            .post(this.realNameAuditApi, qs.stringify(params))
            .then(res => res.data);
    }

    //实名审核用户基本信息
    selectUserAuthenticationInfo(params) {
        return axios
            .post(this.selectUserAuthenticationInfoApi, qs.stringify(params))
            .then(res => res.data);
    }

    //初级实名审核信息
    selectLowAuth(params) {
        return axios
            .post(this.selectLowAuthApi, qs.stringify(params))
            .then(res => res.data);
    }

    //初级实名审核信息
    selectLowRemark(params) {
        return axios
            .post(this.selectLowRemarkApi, qs.stringify(params))
            .then(res => res.data);
    }

    //初级实名审核信息
    selectHighRemark(params) {
        return axios
            .post(this.selectHighRemarkApi, qs.stringify(params))
            .then(res => res.data);
    }

    //高级实名审核信息
    selectHighAuth(params) {
        return axios
            .post(this.selectHighAuthApi, qs.stringify(params))
            .then(res => res.data);
    }

    //提交初级审核
    passLowAuth(params) {
        return axios
            .post(this.passLowAuthApi, qs.stringify(params))
            .then(res => res.data);
    }

    //驳回初级审核
    rejectLowAuth(params) {
        return axios
            .post(this.rejectLowAuthApi, qs.stringify(params))
            .then(res => res.data);
    }

    //提交高级审核
    passHighAuth(params) {
        return axios
            .post(this.passHighAuthApi, qs.stringify(params))
            .then(res => res.data);
    }

    //驳回高级审核
    rejectHighAuth(params) {
        return axios
            .post(this.rejectHighAuthApi, qs.stringify(params))
            .then(res => res.data);
    }

    //查询用户黑白名单
    listUserListByUserId(params) {
        return axios
            .post(this.listUserListByUserIdApi, qs.stringify(params))
            .then(res => res.data);
    }

    //添加黑名单
    addBlacklist(params) {
        return axios
            .post(this.addBlacklistApi, qs.stringify(params))
            .then(res => res.data);
    }

    //添加白名单
    addWhitelist(params) {
        return axios
            .post(this.addWhitelistApi, qs.stringify(params))
            .then(res => res.data);
    }

    //删除黑白名单
    delBlacklist(params) {
        return axios
            .post(this.delBlacklistApi, qs.stringify(params))
            .then(res => res.data);
    }

    //查询用户资产
    listSearchUserAsset(params) {
        return axios
            .post(this.listSearchUserAssetApi, qs.stringify(params))
            .then(res => res.data);
    }

    // 修改用户手机
    updateMobilePhone(params) {
        return axios
            .post(this.updateMobilePhoneApi, qs.stringify(params))
            .then(res => res.data);
    }

    // 修改用户手机
    updateIdentityCode(params) {
        return axios
            .post(this.updateIdentityCodeApi, qs.stringify(params))
            .then(res => res.data);
    }

    //查询用户认证信息
    selectUserAuthentication(params) {
        return axios.post(this.selectUserAuthenticationApi, qs.stringify(params)).then(res => res.data);
    }
})();
/**
 * 登录模块 Login
 */
export const Login = new (class {
    constructor() {
        this.loginApp = loginApi + "/login/login"; //系统用户登录
        this.loginPublicKey = loginApi + "/login/getPublicKey"; //获取公钥
        this.sendLoginCodeApi = loginApi + "/login/sendLoginCode"; //获取验证码
        this.exitLogin = loginApi + "/login/exit"; //系统用户退出登录
    }

    sendLoginCode(params) {
        return axios
            .get(this.sendLoginCodeApi, {
                params: params,
                headers: {
                    requestType: "noToken"
                }
            })
            .then(res => res.data);
    }

    publicKey(params) {
        return axios
            .get(this.loginPublicKey, {
                params: params,
                headers: {
                    requestType: "noToken"
                }
            })
            .then(res => res.data);
    }

    login(params) {
        return axios
            .get(this.loginApp, {
                params: params,
                headers: {
                    requestType: "noToken"
                }
            })
            .then(res => res.data);
    }

    logout() {
        return axios.get(this.exitLogin, {
            headers: {
                requestType: "noToken"
            }
        });
    }
})();

export const SysConf = new (class {
    constructor() {
        //钱包初始额度
        this.insertWalletInitApi = sysconfApi + "/walletInit/insert"; //新增
        this.updWalletInitApi = sysconfApi + "/walletInit/update"; //修改
        this.delWalletInitApi = sysconfApi + "/walletInit/delete"; //删除
        this.getWalletInitListApi = sysconfApi + "/walletInit/list"; //列表
        //版本
        this.insertVersionApi = sysconfApi + "/version/add"; //新增版本
        this.updVersionApi = sysconfApi + "/version/edit"; //修改版本
        this.delVersionApi = sysconfApi + "/version/remove"; //删除版本
        this.getVersionListApi = sysconfApi + "/version/list"; //版本列表
        //补丁
        this.insertWgtVersionApi = sysconfApi + "/wgtVersion/add"; //新增版本
        this.updWgtVersionApi = sysconfApi + "/wgtVersion/edit"; //修改版本
        this.delWgtVersionApi = sysconfApi + "/wgtVersion/remove"; //删除版本
        this.getWgtVersionListApi = sysconfApi + "/wgtVersion/list"; //版本列表
        //联系我们
        this.insertContactUsApi = sysconfApi + "/contactUs/add"; //新增
        this.updContactUsApi = sysconfApi + "/contactUs/edit"; //修改
        this.delContactUsApi = sysconfApi + "/contactUs/remove"; //删除
        this.getContactUsListApi = sysconfApi + "/contactUs/list"; //版本
        //资讯
        this.insertNewsApi = sysconfApi + "/news/add"; //新增
        this.updNewsApi = sysconfApi + "/news/edit"; //修改
        this.delNewsApi = sysconfApi + "/news/remove"; //删除
        this.getNewsListApi = sysconfApi + "/news/list"; //版本
        //帮助中心
        this.insertHelpCenterApi = sysconfApi + "/helpCenter/add"; //新增
        this.updHelpCenterApi = sysconfApi + "/helpCenter/edit"; //修改
        this.delHelpCenterApi = sysconfApi + "/helpCenter/remove"; //删除
        this.getHelpCenterListApi = sysconfApi + "/helpCenter/list"; //版本
        this.selectContentByIdApi = sysconfApi + "/helpCenter/selectContentById"; //根据id查询内容

        //公告
        this.getNoticeListApi = sysconfApi + "/systemNotice/systemNoticeList"; //公告列表
        this.insertNoticeApi = sysconfApi + "/systemNotice/insertSystemNotice"; //新增公告
        this.updNoticeApi = sysconfApi + "/systemNotice/updateSystemNotice"; //修改公告
        this.updNoticeStatusApi =
            sysconfApi + "/systemNotice/updateSystemNoticeStatus"; //修改公告状态
        this.deleteNoticeApi = sysconfApi + "/systemNotice/deleteNotice"; //删除公告
        //轮播图
        this.getImageListApi = sysconfApi + "/systemImage/systemImageList"; //轮播图列表
        this.insertImageApi = sysconfApi + "/systemImage/insertSystemImage"; //新增轮播图
        this.updImageApi = sysconfApi + "/systemImage/updateSystemImage"; //修改轮播图
        this.updImageStatusApi =
            sysconfApi + "/systemImage/updateSystemImageStatus"; //修改轮播图状态
        this.deleteImageApi = sysconfApi + "/systemImage/deleteImage"; //删除轮播图
        //base64存储
        this.uploadSysImageApi = sysconfApi + "/upload/uploadFile"; //上传轮播图
        this.uploadSysFileApi = sysconfApi + "/upload/uploadPDF"; //上传pdf
        //服务协议
        this.insertAgreementApi = sysconfApi + "/agreement/add"; //新增
        this.updAgreementApi = sysconfApi + "/agreement/edit"; //修改
        this.getAgreementListApi = sysconfApi + "/agreement/list"; //列表
        this.deleteAgreementApi = sysconfApi + "/agreement/remove"; //删除
        //项目中心
        this.getWhiteListApi = sysconfApi + "/projectCenter/list"; //列表
        this.insertWhiteApi = sysconfApi + "/projectCenter/add"; //新增
        this.updWhiteApi = sysconfApi + "/projectCenter/edit"; //修改
        this.updWhiteStatusApi = sysconfApi + "/projectCenter/editStatus"; //修改状态
        this.deleteWhiteApi = sysconfApi + "/projectCenter/remove"; //删除
        //项目类型
        this.getClassifyListApi = sysconfApi + "/projectCenterClassify/list"; //列表
        this.insertClassifyApi = sysconfApi + "/projectCenterClassify/add"; //新增
        this.updClassifyApi = sysconfApi + "/projectCenterClassify/edit"; //修改
        this.updClassifyStatusApi = sysconfApi + "/projectCenterClassify/editStatus"; //修改状态
        this.deleteClassifyApi = sysconfApi + "/projectCenterClassify/remove"; //删除
        //项目报告
        this.getReportListApi = sysconfApi + "/projectCenterReport/list"; //列表
        this.insertReportApi = sysconfApi + "/projectCenterReport/add"; //新增
        this.updReportApi = sysconfApi + "/projectCenterReport/edit"; //修改
        this.updReportStatusApi = sysconfApi + "/projectCenterReport/editStatus"; //修改状态
        this.deleteReportApi = sysconfApi + "/projectCenterReport/remove"; //删除
    }

    //钱包初始额度
    insertWalletInit(params) {
        return axios
            .post(this.insertWalletInitApi, qs.stringify(params))
            .then(res => res.data);
    }

    updWalletInit(params) {
        return axios
            .post(this.updWalletInitApi, qs.stringify(params))
            .then(res => res.data);
    }

    delWalletInit(params) {
        return axios
            .post(this.delWalletInitApi, qs.stringify(params))
            .then(res => res.data);
    }

    getWalletInitList(params) {
        return axios
            .get(this.getWalletInitListApi, {
                params: params
            })
            .then(res => res.data);
    }

    //服务协议
    insertAgreement(params) {
        return axios
            .post(this.insertAgreementApi, qs.stringify(params))
            .then(res => res.data);
    }

    updAgreement(params) {
        return axios
            .post(this.updAgreementApi, qs.stringify(params))
            .then(res => res.data);
    }

    delAgreement(params) {
        return axios
            .post(this.deleteAgreementApi, qs.stringify(params))
            .then(res => res.data);
    }

    getAgreementList(params) {
        return axios
            .get(this.getAgreementListApi, {
                params: params
            })
            .then(res => res.data);
    }


    //版本
    insertVersion(params) {
        return axios
            .post(this.insertVersionApi, qs.stringify(params))
            .then(res => res.data);
    }

    updVersion(params) {
        return axios
            .post(this.updVersionApi, qs.stringify(params))
            .then(res => res.data);
    }

    delVersion(params) {
        return axios
            .post(this.delVersionApi, qs.stringify(params))
            .then(res => res.data);
    }

    getVersionList(params) {
        return axios
            .get(this.getVersionListApi, {
                params: params
            })
            .then(res => res.data);
    }

    //补丁
    insertWgtVersion(params) {
        return axios
            .post(this.insertWgtVersionApi, qs.stringify(params))
            .then(res => res.data);
    }

    updWgtVersion(params) {
        return axios
            .post(this.updWgtVersionApi, qs.stringify(params))
            .then(res => res.data);
    }

    delWgtVersion(params) {
        return axios
            .post(this.delWgtVersionApi, qs.stringify(params))
            .then(res => res.data);
    }

    getWgtVersionList(params) {
        return axios
            .get(this.getWgtVersionListApi, {
                params: params
            })
            .then(res => res.data);
    }

    //联系我们
    insertContactUs(params) {
        return axios
            .post(this.insertContactUsApi, qs.stringify(params))
            .then(res => res.data);
    }

    updContactUs(params) {
        return axios
            .post(this.updContactUsApi, qs.stringify(params))
            .then(res => res.data);
    }

    delContactUs(params) {
        return axios
            .post(this.delContactUsApi, qs.stringify(params))
            .then(res => res.data);
    }

    getContactUsList(params) {
        return axios
            .get(this.getContactUsListApi, {
                params: params
            })
            .then(res => res.data);
    }

    //资讯
    insertNews(params) {
        return axios
            .post(this.insertNewsApi, qs.stringify(params))
            .then(res => res.data);
    }

    updNews(params) {
        return axios
            .post(this.updNewsApi, qs.stringify(params))
            .then(res => res.data);
    }

    delNews(params) {
        return axios
            .post(this.delNewsApi, qs.stringify(params))
            .then(res => res.data);
    }

    getNewsList(params) {
        return axios
            .get(this.getNewsListApi, {
                params: params
            })
            .then(res => res.data);
    }

    selectContentById(params) {
        return axios
            .get(this.selectContentByIdApi, {
                params: params
            })
            .then(res => res.data);
    }

    //帮助中心
    insertHelpCenter(params) {
        return axios
            .post(this.insertHelpCenterApi, qs.stringify(params))
            .then(res => res.data);
    }

    updHelpCenter(params) {
        return axios
            .post(this.updHelpCenterApi, qs.stringify(params))
            .then(res => res.data);
    }

    delHelpCenter(params) {
        return axios
            .post(this.delHelpCenterApi, qs.stringify(params))
            .then(res => res.data);
    }

    getHelpCenterList(params) {
        return axios
            .get(this.getHelpCenterListApi, {
                params: params
            })
            .then(res => res.data);
    }

    //公告
    getNoticeList(params) {
        return axios
            .get(this.getNoticeListApi, {
                params: params
            })
            .then(res => res.data);
    }

    insertNotice(params) {
        return axios
            .post(this.insertNoticeApi, qs.stringify(params))
            .then(res => res.data);
    }

    updNotice(params) {
        return axios
            .post(this.updNoticeApi, qs.stringify(params))
            .then(res => res.data);
    }

    updNoticeStatus(params) {
        return axios
            .post(this.updNoticeStatusApi, qs.stringify(params))
            .then(res => res.data);
    }

    deleteNotice(params) {
        return axios
            .post(this.deleteNoticeApi, qs.stringify(params))
            .then(res => res.data);
    }

    //轮播图
    getImageList(params) {
        return axios
            .get(this.getImageListApi, {
                params: params
            })
            .then(res => res.data);
    }

    insertImage(params) {
        return axios
            .post(this.insertImageApi, qs.stringify(params))
            .then(res => res.data);
    }

    updImage(params) {
        return axios
            .post(this.updImageApi, qs.stringify(params))
            .then(res => res.data);
    }

    updImageStatus(params) {
        return axios
            .post(this.updImageStatusApi, qs.stringify(params))
            .then(res => res.data);
    }

    deleteImage(params) {
        return axios
            .post(this.deleteImageApi, qs.stringify(params))
            .then(res => res.data);
    }

    uploadSysImage(params) {
        return axios
            .post(this.uploadSysImageApi, qs.stringify(params))
            .then(res => res.data);
    }

    uploadSysFile(params) {
        return axios.post(this.uploadSysFileApi, params).then(res => res.data);
    }

    //项目中心
    getWhiteList(params) {
        return axios
            .get(this.getWhiteListApi, {
                params: params
            })
            .then(res => res.data);
    }

    insertWhite(params) {
        return axios
            .post(this.insertWhiteApi, qs.stringify(params))
            .then(res => res.data);
    }

    updWhite(params) {
        return axios
            .post(this.updWhiteApi, qs.stringify(params))
            .then(res => res.data);
    }

    updWhiteStatus(params) {
        return axios
            .post(this.updWhiteStatusApi, qs.stringify(params))
            .then(res => res.data);
    }

    deleteWhite(params) {
        return axios
            .post(this.deleteWhiteApi, qs.stringify(params))
            .then(res => res.data);
    }

    //项目类型
    getClassifyList(params) {
        return axios
            .get(this.getClassifyListApi, {
                params: params
            })
            .then(res => res.data);
    }

    insertClassify(params) {
        return axios
            .post(this.insertClassifyApi, qs.stringify(params))
            .then(res => res.data);
    }

    updClassify(params) {
        return axios
            .post(this.updClassifyApi, qs.stringify(params))
            .then(res => res.data);
    }

    updClassifyStatus(params) {
        return axios
            .post(this.updClassifyStatusApi, qs.stringify(params))
            .then(res => res.data);
    }

    deleteClassify(params) {
        return axios
            .post(this.deleteClassifyApi, qs.stringify(params))
            .then(res => res.data);
    }

    //项目中心
    getReportList(params) {
        return axios
            .get(this.getReportListApi, {
                params: params
            })
            .then(res => res.data);
    }

    insertReport(params) {
        return axios
            .post(this.insertReportApi, qs.stringify(params))
            .then(res => res.data);
    }

    updReport(params) {
        return axios
            .post(this.updReportApi, qs.stringify(params))
            .then(res => res.data);
    }

    updReportStatus(params) {
        return axios
            .post(this.updReportStatusApi, qs.stringify(params))
            .then(res => res.data);
    }

    deleteReport(params) {
        return axios
            .post(this.deleteReportApi, qs.stringify(params))
            .then(res => res.data);
    }
})();
/**
 *
 * 角色模块
 */
export const Role = new (class {
    constructor() {
        this.geRoleListApi = loginApi + "/systemRole/systemRoleList"; //角色列表
        this.deleteRoleApi = loginApi + "/systemRole/deleteRole"; //删除角色
        this.insertRoleApi = loginApi + "/systemRole/insertSystemRole"; //新增角色
        this.codeCheckApi = loginApi + "/systemRole/codeCheck"; //角色标识验证
        this.roleMenusApi = loginApi + "/systemRole/roleMenuList"; //角色菜单
        this.setRoleMenusApi = loginApi + "/systemRole/setRoleMenus"; //设置角色菜单
        this.updStatusApi = loginApi + "/systemRole/updateSystemRoleStatus"; //修改角色状态
        this.menuListApi = loginApi + "/systemMenu/systemMenuList"; //全部菜单
    }

    getRoleList(params) {
        return axios
            .get(this.geRoleListApi, {
                params: params
            })
            .then(res => res.data);
    }

    codeCheck(params) {
        return axios
            .get(this.codeCheckApi, {
                params: params
            })
            .then(res => res.data);
    }

    deleteRole(params) {
        return axios
            .post(this.deleteRoleApi, qs.stringify(params))
            .then(res => res.data);
    }

    insertRole(params) {
        return axios
            .post(this.insertRoleApi, qs.stringify(params))
            .then(res => res.data);
    }

    roleMenus(params) {
        return axios
            .get(this.roleMenusApi, {
                params: params
            })
            .then(res => res.data);
    }

    setRoleMenus(params) {
        return axios
            .post(this.setRoleMenusApi, qs.stringify(params))
            .then(res => res.data);
    }

    updStatus(params) {
        return axios
            .post(this.updStatusApi, qs.stringify(params))
            .then(res => res.data);
    }

    menuList(params) {
        return axios
            .get(this.menuListApi, {
                params: params
            })
            .then(res => res.data);
    }
})();
/**
 * 管理员模块
 */
export const Manager = new (class {
    constructor() {
        this.getManagerListApi = loginApi + "/systemUser/systemUserList"; //用户列表
        this.deleteManagerApi = loginApi + "/systemUser/deleteUser"; //删除用户
        this.insertUserApi = loginApi + "/systemUser/insertSystemUser"; //新增用户
        this.accountCheckApi = loginApi + "/systemUser/accountCheck"; //姓名唯一验证
        this.setUserRoleApi = loginApi + "/systemUser/setUserRoles"; //设置用户角色
        this.updStatusApi = loginApi + "/systemUser/updateSystemUserStatus"; //修改用户状态
        this.updNewPasswordApi = loginApi + "/systemUser/updateUserPassword"; //修改密码
        this.updateSystemUserApi = loginApi + "/systemUser/updateSystemUser"; //修改信息
        this.showByIdApi = loginApi + "/systemUser/showById"; //查询个人信息
    }

    showById(params) {
        return axios
            .get(this.showByIdApi, {
                params: params
            })
            .then(res => res.data);
    }

    getManagerList(params) {
        return axios
            .get(this.getManagerListApi, {
                params: params
            })
            .then(res => res.data);
    }

    accountCheck(params) {
        return axios
            .get(this.accountCheckApi, {
                params: params
            })
            .then(res => res.data);
    }

    deleteManager(params) {
        return axios
            .post(this.deleteManagerApi, qs.stringify(params))
            .then(res => res.data);
    }

    insertUser(params) {
        return axios.post(this.insertUserApi, params).then(res => res.data);
    }

    setUserRole(params) {
        return axios
            .post(this.setUserRoleApi, qs.stringify(params))
            .then(res => res.data);
    }

    updateSystemUser(params) {
        return axios
            .post(this.updateSystemUserApi, params)
            .then(res => res.data);
    }

    updStatus(params) {
        return axios
            .post(this.updStatusApi, qs.stringify(params))
            .then(res => res.data);
    }

    updNewPassword(params) {
        return axios
            .post(this.updNewPasswordApi, qs.stringify(params))
            .then(res => res.data);
    }
})();
/**
 * 币币交易模块
 */
export const CCT = new (class {
    constructor() {
        /*订单api*/
        this.cancel = cctApi + "/order/cancel"; //取消订单 P
        this.listFinish = cctApi + "/order/listFinish"; //查询历史订单列表 G
        this.listMatch = cctApi + "/order/listMatch"; //查询挂单列表 G
        /*成交api*/
        this.listRecord = cctApi + "/record/list"; //查询成交记录详情列表 G
        this.recordById = cctApi + "/record/getById"; //根据id查询
        /*配置api*/
        this.listConfig = cctApi + "/config/list"; //查询配置列表 G
        this.configUpdate = cctApi + "/config/update"; //更新配置信息 P
        /*币对api*/
        this.insertCoin = cctApi + "/coin/insert"; //新增币对信息 P
        this.listCoin = cctApi + "/coin/list"; //查询币对列表 G
        this.updateCoin = cctApi + "/coin/update"; //更新币对信息 P
        /*日志api*/
        this.listCoinLog = cctApi + "/log/listCoinLog"; //查询交易币对操作日志列表 G
        this.listOrderLog = cctApi + "/log/listOrderLog"; //查询订单操作日志列表 G
        this.listConfigLog = cctApi + "/log/listConfigLog"; //查询配置操作日志列表 G
        /*自动生成规则*/
        this.listAutomaticdata = cctApi + "/automaticdata/list"; //查询自动生成规则配置 G
        this.insertAutomaticdata = cctApi + "/automaticdata/insert"; //新增自动生成规则配置 P
        this.updateAutomaticdata = cctApi + "/automaticdata/update"; //新增自动生成规则配置 P
        /*撮合配置*/
        this.listMatchConfig = cctApi + "/matchConfig/list"; //查询撮合配置列表 G
        this.insertOrUpdateMatchConfig = cctApi + "/matchConfig/insertOrUpdate"; //新增或更新撮合配置 P
        this.deleteMatchConfig = cctApi + "/matchConfig/delete"; //删除撮合配置 P
        /*佣金配置*/
        this.listCommission = cctApi + "/commission/list"; //查询佣金列表 G
        this.updateCommissionIssueTime = cctApi + "/config/updateCommissionIssueTime"; // 更新佣金发放时间 G
        this.issueCommission = cctApi + "/commission/issueCommission"; // 发放佣金 G
    }

    getListMatch(params) {
        return axios
            .get(this.listMatch, {
                params: params
            })
            .then(res => res.data);
    }

    getListFinish(params) {
        return axios
            .get(this.listFinish, {
                params: params
            })
            .then(res => res.data);
    }

    getListRecord(params) {
        return axios
            .get(this.listRecord, {
                params: params
            })
            .then(res => res.data);
    }

    getRecordById(params) {
        return axios
            .get(this.recordById, {
                params: params
            })
            .then(res => res.data);
    }

    cancelOrder(params) {
        return axios.post(this.cancel, qs.stringify(params)).then(res => res.data);
    }

    getListCoin(params) {
        return axios
            .get(this.listCoin, {
                params: params
            })
            .then(res => res.data);
    }

    handleInsertCoin(params) {
        return axios
            .post(this.insertCoin, qs.stringify(params))
            .then(res => res.data);
    }

    handleUpdateCoin(params) {
        return axios
            .post(this.updateCoin, qs.stringify(params))
            .then(res => res.data);
    }

    getListConfig(params) {
        return axios
            .get(this.listConfig, {
                params: params
            })
            .then(res => res.data);
    }

    handleUpdateConfig(params) {
        return axios
            .post(this.configUpdate, qs.stringify(params))
            .then(res => res.data);
    }

    getListCoinLog(params) {
        return axios
            .get(this.listCoinLog, {
                params: params
            })
            .then(res => res.data);
    }

    getListOrderLog(params) {
        return axios
            .get(this.listOrderLog, {
                params: params
            })
            .then(res => res.data);
    }

    getListConfigLog(params) {
        return axios
            .get(this.listConfigLog, {
                params: params
            })
            .then(res => res.data);
    }

    getListAutomaticdata(params) {
        return axios
            .get(this.listAutomaticdata, {
                params: params
            })
            .then(res => res.data);
    }

    handleInsertAutomaticdata(params) {
        return axios
            .post(this.insertAutomaticdata, qs.stringify(params))
            .then(res => res.data);
    }

    handleUpdateAutomaticdata(params) {
        return axios
            .post(this.updateAutomaticdata, qs.stringify(params))
            .then(res => res.data);
    }

    getListMatchConfig(params) {
        return axios
            .get(this.listMatchConfig, {
                params: params
            })
            .then(res => res.data);
    }

    handleinsertOrUpdateMatchConfig(params) {
        return axios.post(this.insertOrUpdateMatchConfig, qs.stringify(params)).then(res => res.data);
    }

    handleDeleteMatchConfig(params) {
        return axios.post(this.deleteMatchConfig, qs.stringify(params)).then(res => res.data);
    }

    getListCommission(params) {
        return axios
            .get(this.listCommission, {
                params: params
            })
            .then(res => res.data);
    }

    handleIssueCommission(params) {
        return axios
            .get(this.issueCommission, {
                params: params
            })
            .then(res => res.data);
    }

    handleUpdateCommissionIssueTime(params) {
        return axios.post(this.updateCommissionIssueTime, qs.stringify(params)).then(res => res.data);
    }

})();

/**
 * 行情模块
 */
export const Currency = new (class {
    constructor() {
        /*币种*/
        this.listCurrency = currencyApi + "/currency/list"; //查询币种列表 G
        this.insertCurrency = currencyApi + "/currency/insert"; //新增币种 P
        this.updateCurrency = currencyApi + "/currency/update"; //更新币种 P
        /*行情*/
        this.listCurrencyPair = currencyApi + "/currencyPair/list"; //查询行情列表 G
        this.insertCurrencyPair = currencyApi + "/currencyPair/insert"; //新增行情 P
        this.updateCurrencyPair = currencyApi + "/currencyPair/update"; //更新行情 P
        /*app行情接口*/
        this.query = appCurrencyApi + "/market/querySortDesc"; //获取数字货币行情列表 G
    }

    getListCurrency(params) {
        return axios
            .get(this.listCurrency, {
                params: params
            })
            .then(res => res.data);
    }

    handleInsertCurrency(params) {
        return axios
            .post(this.insertCurrency, qs.stringify(params))
            .then(res => res.data);
    }

    handleUpdateCurrency(params) {
        return axios
            .post(this.updateCurrency, qs.stringify(params))
            .then(res => res.data);
    }

    getListCurrencyPair(params) {
        return axios
            .get(this.listCurrencyPair, {
                params: params
            })
            .then(res => res.data);
    }

    handleInsertCurrencyPair(params) {
        return axios
            .post(this.insertCurrencyPair, qs.stringify(params))
            .then(res => res.data);
    }

    handleUpdateCurrencyPair(params) {
        return axios
            .post(this.updateCurrencyPair, qs.stringify(params))
            .then(res => res.data);
    }

    getQuery(params) {
        return axios
            .get(this.query, {
                params: params
            })
            .then(res => res.data);
    }
})();

/**
 * 数据机器人模块
 */
export const Bot = new class {
    constructor() {
        /*币对数据配置信息*/
        this.listConfig = botApi + '/config/list'; //查询币对数据配置列表 G
        this.insertConfig = botApi + '/config/insert'; //新增币对数据配置 P
        this.updateConfig = botApi + '/config/update'; //更新币对数据配置 P
        /*币对数据配置操作日志*/
        this.listConfigHandleLog = botApi + '/configHandleLog/list'; //查询币对数据配置操作日志列表 G
        /*撮合配置信息*/
        this.listMatchConfig = botApi + '/matchConfig/list'; //查询撮合配置列表 G
        this.insertMatchConfig = botApi + '/matchConfig/insert'; //新增撮合配置 P
        this.updateMatchConfig = botApi + '/matchConfig/update'; //更新撮合配置 P
        this.deleteMatchConfig = botApi + '/matchConfig/delete'; //删除撮合配置 P
        /*撮合配置操作日志*/
        this.listMatchConfigHandleLog = botApi + '/matchConfigHandleLog/list' //查询撮合配置操作日志列表 G
    }

    getListConfig(params) {
        return axios.get(this.listConfig, {
            params: params
        }).then(res => res.data);
    }

    handleInsertConfig(params) {
        return axios.post(this.insertConfig, qs.stringify(params)).then(res => res.data);
    }

    handleUpdateConfig(params) {
        return axios.post(this.updateConfig, qs.stringify(params)).then(res => res.data);
    }

    getListConfigHandleLog(params) {
        return axios.get(this.listConfigHandleLog, {
            params: params
        }).then(res => res.data);
    }

    getListMatchConfig(params) {
        return axios.get(this.listMatchConfig, {
            params: params
        }).then(res => res.data);
    }

    handleInsertMatchConfig(params) {
        return axios.post(this.insertMatchConfig, qs.stringify(params)).then(res => res.data);
    }

    handleUpdateMatchConfig(params) {
        return axios.post(this.updateMatchConfig, qs.stringify(params)).then(res => res.data);
    }

    handleDeleteMatchConfig(params) {
        return axios.post(this.deleteMatchConfig, qs.stringify(params)).then(res => res.data);
    }

    getListMatchConfigHandleLog(params) {
        return axios.get(this.listMatchConfigHandleLog, {
            params: params
        }).then(res => res.data);
    }
}

/***
 * BTC模块
 */
export const Btc = wallet.getWellet(btcApi);

/***
 * ETH模块
 */
export const Eth = wallet.getWellet(ethApi);

/***
 * EOS模块
 */
export const Eos = wallet.getWellet(eosApi);

/***
 * OTC模块
 */
export const Otc = new OtcApi(c2cApi);
