/** 工具类 */
import routeList from '@/common/js/route-list.js'; //全部路由item

const USERMANAGE = 'UserManage'; //用户管理
const ORDERMANAGE = 'OrderManage'; //订单管理
const MANAGE = 'Manage'; //管理员管理
const COST = 'Cost'; //手续费管理
const CAPITAL = 'Capital'; //资金管理
const ASSETCOLLECTION = 'AssetCollection'; //资产归集
const CURRENCY = 'Currency'; //货币管理
const SYSTEM = 'System'; //系统管理
const LOG = 'Log'; //日志管理
const ACCOUNTMANAGE = 'AccountManage'; //账户管理
const OTC = 'OtcManage'; //法币管理
const MATCH = 'MatchManage'; //撮合管理
const BOT = 'Bot'; //K线机器人
const MATCHBOT = 'MatchBot'; //撮合机器人
const MARKETUSER = 'MarketUser'; //市商用户
const COMMISSION = 'Commission'; //币币佣金管理
class Utils {
    constructor(curRoutes = null, routes = []) {
        this.curRoutes = curRoutes;
        this.routes = routes;
    }

    /**
     * getRoutes 根据用户构建路由表
     * @param {用户路由表} routes
     */
    getRoutes(routes) {
        this._filterRoutes(routes);
        for (let parent of [...this.routes]) {
            if (parent.name in this.curRoutes) {
                for (let children of this.curRoutes[parent.name]) {
                    if (!routeList[children]) continue;
                    parent.children.push(routeList[children]);
                    this._addDetail(children, parent);
                }
            }
        }
        return [...this.routes];
    }

    /**
     * filterRoutes 父子路由的组装
     * @param {用户的路由表} routes
     */
    _filterRoutes(routes) {
        let [UserManage, OrderManage, Manage, Cost, Capital, AssetCollection, Currency, System,
            Log, AccountManage, OtcManage, MatchManage, Bot, MatchBot, MarketUser, Commission] = [
            [],
            [],
            [],
            [],
            [],
            [],
            [],
            [],
            [],
            [],
            [],
            [],
            [],
            [],
            [],
            []
        ];
        this.curRoutes = {
            UserManage,
            OrderManage,
            Manage,
            Cost,
            Capital,
            AssetCollection,
            Currency,
            System,
            Log,
            AccountManage,
            OtcManage,
            MatchManage,
            Bot,
            MatchBot,
            MarketUser,
            Commission,
        };
        for (let i = 0; i < routes.length; i++) {
            if (routes[i].pid) {
                switch (routes[i].pid) {
                    case '7232ed54-d5cb-42c8-be96-390b35405354':
                        UserManage.push(routes[i].code);
                        this.routes.push(routeList[USERMANAGE]);
                        break;
                    case '297ee11f-0ef7-4c49-8751-94c024809ef0':
                        OrderManage.push(routes[i].code);
                        this.routes.push(routeList[ORDERMANAGE])
                        break;
                    case '1fd94c16-4147-489f-ae82-63560b7e5195':
                        Manage.push(routes[i].code);
                        this.routes.push(routeList[MANAGE])
                        break;
                    case '4454e6d1-35f3-4102-85f6-a9264172171b':
                        Cost.push(routes[i].code);
                        this.routes.push(routeList[COST])
                        break;
                    case 'ffe1a687-f55b-488c-b844-7d560d17cbd7':
                        Capital.push(routes[i].code);
                        this.routes.push(routeList[CAPITAL])
                        break;
                    case '08889ddc-45ff-4279-a56e-a12f0b48e394':
                        AssetCollection.push(routes[i].code);
                        this.routes.push(routeList[ASSETCOLLECTION])
                        break;
                    case 'b4652551-0bec-43db-8274-3d9568f3ced0':
                        Currency.push(routes[i].code);
                        this.routes.push(routeList[CURRENCY])
                        break;
                    case 'a203da0b-a054-4900-83e1-48c328d01fe3':
                        System.push(routes[i].code);
                        this.routes.push(routeList[SYSTEM])
                        break;
                    case '8ff39325-6500-40ac-8add-6286fe8e6f57':
                        Log.push(routes[i].code);
                        this.routes.push(routeList[LOG])
                        break;
                    case '33f0e92c-46ea-4f1c-bfb8-89065bfea71e':
                        AccountManage.push(routes[i].code);
                        this.routes.push(routeList[ACCOUNTMANAGE])
                        break;
                    case 'a63199c1-7905-4707-9e5a-a0ff93ba27d3':
                        OtcManage.push(routes[i].code);
                        this.routes.push(routeList[OTC])
                        break;
                    case '2f13401e-92a9-41db-ac63-8bf2e51ce4dd':
                        MatchManage.push(routes[i].code);
                        this.routes.push(routeList[MATCH])
                        break;
                    case 'e96a98cf-226d-48f2-8a3f-8c94b7e30305':
                        Bot.push(routes[i].code);
                        this.routes.push(routeList[BOT])
                        break;
                    case '0330a3fc-3dc9-4d6a-a76a-c3f5105c847d':
                        MatchBot.push(routes[i].code);
                        this.routes.push(routeList[MATCHBOT])
                        break;
                    case '871eb662-5681-457c-a5c8-c00b2b79f8da':
                        MarketUser.push(routes[i].code);
                        this.routes.push(routeList[MARKETUSER])
                        break;
                    case '30de719b-bfba-4cfc-ae35-e024e68270a8':
                        Commission.push(routes[i].code);
                        this.routes.push(routeList[COMMISSION])
                        break;
                }
            }

        }
        this.routes = new Set(this.routes)
    }

    /**
     * addDetail 添加对应页的详情子路由 （如果用户路由表没有带出的话就需要调用）
     * @param {子路由} children
     * @param {父级路由} parent
     */
    _addDetail(children, parent) {
        switch (children) {
            case 'UserList':
                parent.children.push(routeList['UserDetail']);
                break;
            case 'UserAsset':
                parent.children.push(routeList['AssetDetail']);
                break;
            case 'Certification':
                parent.children.push(routeList['CertifyDetail']);
                break;
            case 'Role':
                parent.children.push(routeList['Authority']);
                parent.children.push(routeList['AuthorityTree']); //树状
                break;
            case 'WaitFirstExam':
                parent.children.push(routeList['FirstExamDetail']);
                break;
            case 'WaitAgainExam':
                parent.children.push(routeList['AgainExamDetail']);
                break;
            case 'WaitOut':
                parent.children.push(routeList['WaitOutDetail']);
                break;
            case 'ErrorOut':
                parent.children.push(routeList['ErrorOutDetail']);
                break;
            case 'CapitalWithdraw':
                parent.children.push(routeList['WithdrawDetail']);
                break;
            case 'CurrencyList':
                parent.children.push(routeList['AddCurrency']);
                break;
            case 'CurrencyPairList':
                parent.children.push(routeList['AddCurrencyPair']);
                break;
            case 'BCoinList':
                parent.children.push(routeList['BCoinListDetail']);
                break;
            case 'BCoinHistoryList':
                parent.children.push(routeList['BCoinHistoryListDetail']);
                break;
            case 'CurrencyTrade':
                parent.children.push(routeList['TradeAdd']);
                break;
            case 'OtcCoin':
                parent.children.push(routeList['OtcCoinUpdate']);
                break;
            case 'FOrderList':
                parent.children.push(routeList['FOrderAdd']);
                break;
            case 'C2CUserPay':
                parent.children.push(routeList['C2CUserPayAdd']);
                break;
            case 'Automaticdata':
                parent.children.push(routeList['AddAutomaticdata']);
                break;
            case 'OtcAppeal':
                parent.children.push(routeList['OtcAppealDetail']);
                break;
            case 'OtcAdList':
                parent.children.push(routeList['OtcAdDetail']);
                break;
            case 'Manager':
                parent.children.push(routeList['Myself']);
                break;
            case 'CCTMatchConfig':
                parent.children.push(routeList['CCTMatchConfigHandle']);
                break;
            case 'BotCurrencyConfig':
                parent.children.push(routeList['BotCurrencyConfigHandle']);
                break;
            case 'BotMatchConfig':
                parent.children.push(routeList['BotMatchConfigHandle']);
                break;
            case 'WhitePaper':
                parent.children.push(routeList['ProjectReport']);
                break;
        }
    }

    /**
     * 询问alert
     * @param {vue实例} _vue
     * @param {标题} title
     * @param {内容} content
     * @param {回调} callback
     */
    elAlert(_vue, title, content, callback) {
        _vue.$alert(content, title, {
            confirmButtonText: '确定',
            callback: callback
        });
    }

    /**
     * 图片上传 base64 格式
     * @param {图片上传的file} file
     * @param {回调} callback
     */
    uploadImg(_vue, file, callback) {
        if (file.type == "image/gif" || file.type == "image/jpeg" || file.type == "image/jpg" || file.type == "image/bmp" || file.type == "image/png") {
        } else {
            _vue.$message("请上传正确的图片类型");
            return;
        }
        let reader = new FileReader();
        reader.onload = function (e) {
            callback(reader.result);
        }
        reader.readAsDataURL(file);
    }

    /**
     * 限制大小的上传图片
     * @param {vue} _vue
     * @param {图片} file
     * @param {回调} callback
     */
    uploadImgLimit(_vue, file, callback) {
        console.log(file.type)
        if (file.type == "image/gif" || file.type == "image/jpeg" || file.type == "image/jpg" || file.type == "image/bmp" || file.type == "image/png") {

        } else {
            _vue.$message("请上传正确的图片类型");
            return;
        }
        let reader = new FileReader();
        reader.addEventListener("load", function () {
            let image = new Image();
            image.src = reader.result;
            let url = reader.result;
            image.onload = function () {
                var cvs = document.createElement("canvas");
                var scale = 1;
                if (this.width > 1000 || this.height > 1000) { //1000只是示例，可以根据具体的要求去设定
                    if (this.width > this.height) {
                        scale = 1000 / this.width;
                    } else {
                        scale = 1000 / this.height;
                    }
                }
                ;
                cvs.width = this.width * scale;
                cvs.height = this.height * scale;
                var ctx = cvs.getContext("2d");
                ctx.drawImage(this, 0, 0, cvs.width, cvs.height);
                var urlScale = 1;
                if (url.length > 204800) {
                    urlScale = url.length / 204800
                    if (urlScale > 0 && urlScale <= 10) {
                        urlScale = urlScale / 10;
                        var a = urlScale - 1;
                        urlScale = urlScale - a;
                    }
                    if (urlScale > 10 && urlScale <= 20) {
                        urlScale = urlScale / 20;
                        urlScale = urlScale / 10;
                        var a = urlScale - 1;
                        urlScale = urlScale - a;
                    }
                }
                let newImageData = cvs.toDataURL("image/jpeg", urlScale);
                callback(newImageData);
            }
        }, false);
        reader.readAsDataURL(file);
    }
}

export default new Utils();